import { CharacterType, IPosition, ItemType, SlotInfo, SlotType, WeaponType } from "./adventureland";
export declare type GData2 = {
    achievements: {
        [T in AchievementName]: {
            name: string;
            explanation?: string;
            item?: ItemName;
            shells?: number;
            count?: number;
            title?: TitleName;
            rr?: number;
        };
    };
    animations: {
        [T in AnimationName]: {
            aspeed?: "fast" | "mild" | "slow";
            alpha?: number;
            bubble?: boolean;
            continuous?: boolean;
            directional?: boolean;
            exact?: boolean;
            fade?: boolean;
            framefps?: number;
            front?: boolean;
            file: string;
            frames: number;
            proportional?: boolean;
            scale?: number;
            size?: number;
            speed?: number;
            speeding?: boolean;
            tiling?: boolean;
            y?: number;
        };
    };
    classes: {
        [T in CharacterType]: {
            base_slots: Partial<SlotInfo>;
            brave?: boolean;
            damage_type: DamageType;
            description: string;
            doublehand: {
                [T in WeaponType]?: {
                    [T in Attribute]?: number;
                };
            };
            looks: [
                string,
                {
                    chin?: string;
                    hair?: string;
                    hat?: string;
                    head?: string;
                    makeup?: string;
                }
            ][];
            lstats: {
                dex: number;
                for: number;
                int: number;
                str: number;
                vit: number;
            };
            healing_projectile?: string;
            main_stat: Attribute;
            mainhand: {
                [T in WeaponType]?: {
                    [T in Attribute]?: number;
                };
            };
            offhand: {
                [T in WeaponType]?: {
                    [T in Attribute]?: number;
                };
            };
            projectile: string;
            side_stat?: Attribute;
            stats: {
                dex: number;
                for: number;
                int: number;
                str: number;
                vit: number;
            };
            xcx?: any[];
        } & {
            [T in Attribute]?: number;
        };
    };
    conditions: {
        [T in ConditionName]: {
            attr0?: string;
            aura?: boolean;
            name: string;
            explanation?: string;
            bad?: boolean;
            blocked?: boolean;
            buff?: boolean;
            can_move?: boolean;
            channel?: boolean;
            persistent?: boolean;
            interval?: number;
            duration?: number;
            ui?: boolean;
            skin?: string;
            technical?: boolean;
        } & {
            [T in Exclude<Attribute, "attr0">]?: number;
        };
    } & {
        "eburn": {
            damage: number;
            intensity: string;
        };
    } & {
        "reflection": {
            cap_reflection: number;
        };
    };
    craft: {
        [T in ItemName]?: {
            items: [number, ItemName, number?][];
            cost: number;
            quest?: "mcollector" | "witch";
        };
    };
    dimensions: {
        [T in MonsterName | "default_character"]?: [number, number, number?, number?, number?];
    };
    dismantle: {
        [T in ItemName]?: {
            items: [number, ItemName][];
            cost: number;
        };
    };
    drops: {
        [T in DropName]: GDropItem[];
    } | {
        gold: {
            base: number;
            random: number;
            x10: number;
            x50: number;
        };
    } | {
        maps: {
            [T in MapName | "global" | "global_static"]?: GDropItem[];
        };
    } | {
        monsters: {
            [T in MonsterName]?: GDropItem[];
        };
    } | {
        skins: {
            bronze: string[];
            gold: string[];
            normal: string[];
            silver: string[];
        };
    };
    emotions: {
        [T in EmotionName]?: {
            cooldown: number;
            fx: EmotionName;
        };
    };
    geometry: {
        [T in Exclude<MapName, "batcave" | "d1" | "d2" | "d3" | "frozencave" | "maintest" | "old_bank" | "old_main" | "original_main" | "therush">]: {
            default?: number;
            groups?: ([number, number, number] | [number, number, number, any, any, number])[][];
            max_x: number;
            max_y: number;
            min_x: number;
            min_y: number;
            placements: ([number, number, number] | [number, number, number, number, number])[];
            points?: {
                [T in string]: [number, number];
            };
            polygons?: {
                [T in string]: [number, number][];
            };
            rectangles?: {
                [T in string]: [number, number, number, number];
            };
            tiles: ([TilesetName, number, number, number] | [TilesetName, number, number, number, number])[];
            x_lines?: [number, number, number][];
            y_lines?: [number, number, number][];
        };
    };
    items: {
        [T in ItemName]: GItem;
    };
    levels: {
        [T in string]?: number;
    };
    maps: {
        [T in Exclude<MapName, "d1" | "d3" | "frozencave" | "maintest" | "therush">]: {
            data?: {
                min_x: number;
                max_x: number;
                min_y: number;
                max_y: number;
            };
            pvp?: boolean;
            safe?: boolean;
            safe_pvp?: boolean;
            loss?: false;
            on_death?: [MapName, number];
            on_exit?: [MapName, number];
            drop_norm?: number;
            monsters?: {
                boundary?: [number, number, number, number];
                boundaries?: [MapName, number, number, number, number][];
                rage?: [number, number, number, number];
                polygon?: [number, number][];
                count: number;
                gatekeeper?: boolean;
                grow?: boolean;
                type: MonsterName;
                stype?: "randomrespawn";
                roam?: boolean;
                special?: boolean;
                position?: [number, number];
                radius?: number;
            }[];
            npcs: {
                position?: [number, number, number?];
                positions?: [number, number, number?][];
                boundary?: [number, number, number, number];
                loop?: boolean;
                id: NPCName;
                name?: string;
            }[];
            doors: [number, number, number, number, MapName, number?, number?, ("key" | "protected" | "ulocked")?, (ItemName | "complicated")?][];
            key: string;
            name: string;
            instance?: boolean;
            irregular?: boolean;
            mount?: boolean;
            no_bounds?: boolean;
            ignore?: boolean;
            quirks?: [number, number, number, number, "compound" | "info" | "invisible_statue" | "list_pvp" | "log" | "note" | "sign" | "the_lever" | "upgrade" | string, string?][];
            burn_multiplier?: number;
            freeze_multiplier?: number;
            spawns: ([number, number, number?, number?])[];
            world?: string;
            traps?: {
                type: "debuff" | "spikes";
                polygon?: [number, number][];
                position?: [number, number];
            }[];
            animatables?: {
                [T in string]?: {
                    x: number;
                    y: number;
                    position: string;
                };
            };
            event?: string;
            machines?: any;
            unlist?: boolean;
            fx?: string;
            weather?: string;
            zones?: {
                drop: string;
                type: "fishing" | "mining";
                polygon: [number, number][];
            }[];
            ref?: {
                [T in string]?: [number, number] | [number, number, number, number] | IPosition;
            };
            old_monsters?: {
                count: number;
                boundary: [number, number, number, number];
                type: MonsterName;
            }[];
        };
    };
    monsters: {
        [T in Exclude<MonsterName, "terracota">]: GMonster;
    };
    npcs: {
        [T in NPCName]: {
            allow?: boolean;
            aspeed?: "slow" | "slower" | "fast";
            atype?: "flow" | "once";
            aura?: {
                [T in Attribute]?: number;
            };
            color?: string;
            cx?: any;
            delay?: number;
            id: NPCName;
            ignore?: boolean;
            interaction?: string[];
            interval?: number;
            items?: ItemName[];
            level?: number;
            moving?: boolean;
            name?: string;
            old_items?: ItemName[];
            old_role?: "merchant" | "premium";
            old_side_interaction?: {
                auto: boolean;
                message: string;
                skin: string;
            };
            pack?: BankPackName;
            quest?: QuestName;
            role: "announcer" | "blocker" | "bouncer" | "citizen" | "companion" | "compound" | "craftsman" | "cx" | "daily_events" | "exchange" | "funtokens" | "gold" | "guard" | "items" | "jailer" | "locksmith" | "lostandfound" | "lotterylady" | "mcollector" | "merchant" | "monstertokens" | "newupgrade" | "newyear_tree" | "petkeeper" | "premium" | "pvp_announcer" | "pvptokens" | "quest" | "repeater" | "resort" | "rewards" | "secondhands" | "shells" | "ship" | "shrine" | "standmerchant" | "tavern" | "tease" | "thesearch" | "transport" | "witch" | string;
            says?: string[] | string;
            side_interaction?: {
                auto: boolean;
                message: string;
                skin: string;
            };
            skin: string;
            speed?: number;
            stand?: string;
            steps?: number;
            stopframe?: number;
            token?: ItemName;
            type?: "full" | "fullstatic" | "static";
        } & {
            [T in Attribute]?: number;
        };
    } & {
        "transporter": {
            places?: {
                [T in MapName]?: number;
            };
        };
    };
    positions: {
        [T in string]: [string, number, number] | [string, number, number, number, number] | [string, number, number, number, number][];
    } | {
        "textures": string[];
    };
    projectiles: {
        [T in ProjectileName]: {
            animation: string;
            hit_animation?: string;
            pure?: boolean;
            ray?: boolean;
            speed: number;
        };
    };
    shells_to_gold: number;
    skills: {
        [T in SkillName]: {
            action?: string;
            apiercing?: number;
            aura?: boolean;
            class?: CharacterType[];
            code?: boolean | string;
            complementary?: string;
            condition?: ConditionName;
            consume?: ItemName;
            cooldown?: number;
            cooldown_multiplier?: number;
            damage?: number;
            damage_multiplier?: number;
            damage_type?: DamageType;
            duration?: number;
            explanation?: string;
            hostile?: boolean;
            inventory?: ItemName[];
            level?: number;
            levels?: [number, number][];
            list?: boolean;
            max?: number;
            monsters?: boolean;
            mp?: number;
            name: string;
            negative?: ItemName[];
            nprop?: Attribute[];
            output?: number;
            party?: boolean;
            passive?: boolean;
            persistent?: boolean;
            positive?: ItemName[];
            range?: number;
            range_bonus?: number;
            range_multiplier?: number;
            ratio?: number;
            requirements?: {
                [T in Attribute]?: number;
            };
            reuse_cooldown?: number;
            share?: SkillName;
            skin?: string;
            skins?: string[];
            slot?: [SlotType, ItemName][];
            target?: boolean;
            targets?: boolean;
            toggle?: boolean;
            type?: "ability" | "gm" | "monster" | "passive" | "skill" | "utility";
            ui?: boolean;
            warning?: string;
            wtype?: WeaponType | WeaponType[];
            variance?: number;
        };
    };
    tilesets: {
        [T in TilesetName]: {
            file: string;
            frames?: number;
            frame_width?: number;
        };
    };
    titles: {
        [T in TitleName]: {
            title: string;
            type: "all_items" | string;
            achievement?: string;
            source?: string;
            misc?: boolean;
            improve?: boolean;
            manual?: boolean;
        } & {
            [T in Attribute]?: number;
        };
    } & {
        "sniper": {
            consecutive_200p_range_last_hits: number;
        };
    };
    tokens: {
        [T in "funtoken" | "monstertoken" | "pvptoken"]: {
            [T in ItemName]?: number;
        };
    };
    version: number;
};
export declare type GItem = {
    a?: boolean | number;
    ability?: "burn" | "freeze" | "posion" | "poke" | "restore_mp" | "secondchance" | "sugarrush" | "weave" | SkillName;
    acolor?: string;
    action?: string;
    aura?: ConditionName;
    cash?: number;
    class?: CharacterType[];
    compound?: {
        [T in Attribute]?: number;
    };
    cooldown?: number;
    credit?: string;
    cx?: {
        accent?: string;
        border?: number;
        extension?: boolean;
        large?: boolean;
        lightborder?: boolean;
        scale?: number;
    };
    damage?: DamageType;
    days?: number;
    debuff?: boolean;
    delia?: string;
    duration?: number;
    eat?: boolean;
    edge?: number;
    e?: number;
    event?: boolean;
    exclusive?: boolean;
    explanation?: string;
    extra_stat?: number;
    g: number;
    gain?: Attribute;
    gives?: [[Attribute, number]];
    grade?: number;
    grades?: [number, number, number, number];
    hat?: string;
    ignore?: boolean;
    legacy?: {
        class?: null;
        gold?: number;
        luck?: number;
        set?: null;
    };
    markup?: number;
    monster?: MonsterName;
    multiplier?: number;
    name: string;
    nopo?: string;
    note?: string;
    npc?: NPCName;
    offering?: number;
    onclick?: string;
    opens?: MapName;
    projectile?: ProjectileName;
    projectile_test?: string;
    protection?: boolean;
    quest?: string;
    rare?: boolean;
    reward?: number;
    s?: number | boolean;
    scroll?: boolean;
    set?: string;
    skin: string;
    skin_a?: string;
    skin_c?: string;
    skin_r?: string;
    spawn?: MonsterName;
    special?: boolean;
    stand?: string;
    stat?: Attribute | number;
    tier?: number;
    trex?: string;
    type: ItemType;
    unlocks?: MapName;
    upgrade?: {
        [T in Attribute]?: number;
    };
    withdrawal?: ConditionName;
    wtype?: WeaponType;
    xcx?: string[];
    xscroll?: boolean;
} & {
    [T in Exclude<Attribute, "stat">]?: number;
};
export declare type GDropItem = [number, ItemName, number?] | [number, "cx" | "cxbundle", string] | [number, "cxjar", number, string] | [number, "emotionjar", number, EmotionName] | [number, "empty"] | [number, "gold" | "shells", number] | [number, "open", DropName];
export declare type GMonster = {
    "1hp"?: boolean;
    aa?: number;
    abilities?: {
        [T in SkillName]?: {
            cooldown: number;
            radius?: number;
            aura?: boolean;
            condition?: ConditionName;
        };
    } & {
        "burn"?: {
            unlimited: boolean;
            attr0: number;
        };
    } & {
        "degen"?: {
            amount: number;
        };
    } & {
        "heal"?: {
            heal: number;
        };
    } & {
        "multi_burn"?: {
            damage: number;
        };
    } & {
        "putrid"?: {
            curse: boolean;
            poison: boolean;
        };
    } & {
        "self_healing"?: {
            heal: number;
        };
    } & {
        "weakness_aura"?: {
            condition: "weakness";
        };
    } & {
        "zap"?: {
            amount: number;
        };
    };
    achievements?: [number, "stat", Attribute, number][];
    aggro: number;
    announce?: string;
    article?: string;
    attack: number;
    balance?: string;
    charge?: number;
    cooperative?: boolean;
    cute?: boolean;
    damage_type: DamageType;
    difficulty?: number;
    escapist?: boolean;
    explanation?: string;
    frequency: number;
    global?: boolean;
    goldsteal?: number;
    hit?: string;
    hp: number;
    humanoid?: boolean;
    immune?: boolean;
    lucrativeness?: number;
    mp: number;
    name: string;
    operator?: boolean;
    orientation?: number;
    passive?: boolean;
    pet?: {
        aggression: [number, number];
        brightness: number;
        chatter: [number, number];
        courage: [number, number];
        exponential: boolean;
        level: {
            [T in Attribute]?: number;
        };
        obedience: [number, number];
        passion: [number, number];
        xp: number;
    };
    poisonous?: boolean;
    prefix?: string;
    projectile?: string;
    rage: number;
    range: number;
    rbuff?: ConditionName;
    respawn: number;
    roam?: boolean;
    s?: {
        [T in ConditionName]?: {
            ms: number;
        };
    };
    size?: number;
    skin: string;
    slots?: Partial<SlotInfo>;
    spawns?: [number, MonsterName][];
    special?: boolean;
    speed: number;
    stationary?: boolean;
    supporter?: boolean;
    trap?: boolean;
    unlist?: boolean;
    xp: number;
} & {
    [T in Attribute]?: number;
};
export declare type Attribute = "apiercing" | "armor" | "attack" | "attr0" | "attr1" | "avoidance" | "awesomeness" | "blast" | "bling" | "breaks" | "charge" | "charisma" | "courage" | "crit" | "critdamage" | "cuteness" | "dex" | "dreturn" | "evasion" | "explosion" | "firesistance" | "for" | "frequency" | "frequencym" | "fzresistance" | "gold" | "heal" | "healm" | "hp" | "int" | "lifesteal" | "luck" | "manasteal" | "mcourage" | "miss" | "mp" | "mp_cost" | "mp_reduction" | "output" | "pcourage" | "pnresistance" | "potionsm" | "random_stat" | "range" | "reflection" | "resistance" | "rpiercing" | "set_speed" | "speed" | "stat" | "str" | "stun" | "vit" | "xp";
export declare type AchievementName = "1000boss" | "100boss" | "discoverlair" | "festive" | "firehazard" | "gooped" | "lucky" | "monsterhunter" | "reach40" | "reach50" | "reach60" | "reach70" | "reach80" | "reach90" | "stomped" | "upgrade10";
export declare type AnimationName = "acid" | "arrow1" | "arrow_hit" | "block" | "burst" | "carrow" | "confetti" | "crackle" | "cuarrow" | "curse" | "curse_new" | "curse_projectile" | "dampened" | "exchange" | "explode_a" | "explode_b" | "explode_c" | "explode_p" | "explode_up" | "failure" | "firearrow" | "fireball" | "fog" | "frostarrow" | "frostball" | "garrow" | "gm" | "gold" | "gold_anim" | "hardshell" | "heal" | "heal_projectile" | "hearts_single" | "icecrack" | "invincible" | "light" | "magic0" | "magic1" | "magic2" | "magic3" | "magic4" | "mblob" | "mblob_purplish" | "mblob_red" | "mluck" | "party_heal" | "pblob" | "pinky" | "poucharrow" | "rain" | "reflection" | "revival" | "rspeed" | "slash" | "slash0" | "slash1" | "slash2" | "slash3" | "snow" | "snowball" | "snowball_hit" | "snowflake" | "spark0" | "starkiller" | "stunned" | "success" | "superarrow" | "supershot" | "tangle" | "taunt" | "tiling_burst" | "tiling_burstj" | "transport" | "typing" | "wandy" | "wslash";
export declare type BankPackName = "items0" | "items1" | "items2" | "items3" | "items4" | "items5" | "items6" | "items7" | "items8" | "items9" | "items10" | "items11" | "items12" | "items13" | "items14" | "items15" | "items16" | "items17" | "items18" | "items19" | "items20" | "items21" | "items22" | "items23" | "items24" | "items25" | "items26" | "items27" | "items28" | "items29" | "items30" | "items31" | "items32" | "items33" | "items34" | "items35" | "items36" | "items37" | "items38" | "items39" | "items40" | "items41" | "items42" | "items43" | "items44" | "items45" | "items46" | "items47";
export declare type ConditionName = "authfail" | "blink" | "burned" | "charging" | "charmed" | "cursed" | "dampened" | "darkblessing" | "easterluck" | "eburn" | "eheal" | "energized" | "fingered" | "fishing" | "frozen" | "fullguard" | "hardshell" | "holidayspirit" | "invincible" | "invis" | "licenced" | "marked" | "massproduction" | "massproductionpp" | "mcourage" | "mlifesteal" | "mluck" | "monsterhunt" | "mshield" | "notverified" | "phasedout" | "poisoned" | "poisonous" | "power" | "reflection" | "rspeed" | "sanguine" | "shocked" | "slowness" | "stack" | "stoned" | "stunned" | "sugarrush" | "tangled" | "town" | "warcry" | "weakness" | "withdrawal" | "xpower" | "xshotted";
export declare type DamageType = "heal" | "magical" | "none" | "physical" | "pure";
export declare type DropName = "5bucks" | "abtesting" | "apologybox" | "armorbox" | "armorx" | "basicelixir" | "basketofeggs" | "bugbountybox" | "candy0" | "candy0v2" | "candy0v3" | "candy1" | "candy1v2" | "candy1v3" | "candycane" | "candypop" | "cosmo0" | "cosmo1" | "cosmo2" | "cosmo3" | "eastereggs" | "f1" | "gem0" | "gem1" | "gem1_old" | "gemfragment" | "gift0" | "gift1" | "glitch" | "goldenegg" | "greenenvelope" | "jewellerybox" | "konami" | "leather" | "lightmage" | "lostearring0" | "lostearring1" | "lostearring2" | "lostearring3" | "lostearring4" | "m1" | "mistletoe" | "mysterybox" | "ornament" | "quiver" | "redenvelope" | "redenvelopev2" | "redenvelopev2_shouldhavebeen" | "redenvelopev3" | "seashell" | "statamulet" | "statbelt" | "statring" | "test" | "thrash" | "troll" | "weaponbox" | "weaponofthedead" | "xN" | "xbox";
export declare type EmotionName = "drop_egg" | "hearts_single";
export declare type ItemName = "5bucks" | "ale" | "amuletofm" | "angelwings" | "apiercingscroll" | "apologybox" | "armorbox" | "armorring" | "armorscroll" | "ascale" | "axe3" | "bandages" | "basher" | "basketofeggs" | "bataxe" | "bcandle" | "bcape" | "beewings" | "bfang" | "bfur" | "bkey" | "blade" | "blue" | "bottleofxp" | "bow" | "bow4" | "bowofthedead" | "bronzeingot" | "bronzenugget" | "brownegg" | "btusk" | "bugbountybox" | "bunnyears" | "bunnyelixir" | "bwing" | "cake" | "candy0" | "candy0v2" | "candy0v3" | "candy1" | "candy1v2" | "candy1v3" | "candycane" | "candycanesword" | "candypop" | "cape" | "carrot" | "carrotsword" | "cclaw" | "cdarktristone" | "cdragon" | "cearring" | "charmer" | "chrysalis0" | "claw" | "coal" | "coat" | "coat1" | "cocoon" | "computer" | "confetti" | "cosmo0" | "cosmo1" | "cosmo2" | "cosmo3" | "cosmo4" | "crabclaw" | "cring" | "critscroll" | "crossbow" | "cryptkey" | "cscale" | "cscroll0" | "cscroll1" | "cscroll2" | "cscroll3" | "cshell" | "ctristone" | "cupid" | "cxjar" | "cyber" | "dagger" | "daggerofthedead" | "darktristone" | "dartgun" | "dexamulet" | "dexbelt" | "dexearring" | "dexearringx" | "dexring" | "dexscroll" | "dkey" | "dragondagger" | "drapes" | "dreturnscroll" | "dstones" | "ecape" | "ectoplasm" | "eears" | "egg0" | "egg1" | "egg2" | "egg3" | "egg4" | "egg5" | "egg6" | "egg7" | "egg8" | "eggnog" | "electronics" | "elixirdex0" | "elixirdex1" | "elixirdex2" | "elixirfires" | "elixirfzres" | "elixirint0" | "elixirint1" | "elixirint2" | "elixirluck" | "elixirpnres" | "elixirstr0" | "elixirstr1" | "elixirstr2" | "elixirvit0" | "elixirvit1" | "elixirvit2" | "emotionjar" | "emptyheart" | "emptyjar" | "epyjamas" | "eslippers" | "espresso" | "essenceofether" | "essenceoffire" | "essenceoffrost" | "essenceofgreed" | "essenceoflife" | "essenceofnature" | "evasionscroll" | "exoarm" | "fallen" | "fcape" | "fclaw" | "feather0" | "fieldgen0" | "fierygloves" | "figurine" | "fireblade" | "firebow" | "firecrackers" | "firestaff" | "firestars" | "flute" | "forscroll" | "frankypants" | "frequencyscroll" | "frogt" | "frostbow" | "froststaff" | "frozenkey" | "frozenstone" | "fsword" | "ftrinket" | "funtoken" | "fury" | "gbow" | "gcape" | "gem0" | "gem1" | "gem2" | "gem3" | "gemfragment" | "ghatb" | "ghatp" | "gift0" | "gift1" | "glitch" | "gloves" | "gloves1" | "goldbooster" | "goldenegg" | "goldenpowerglove" | "goldingot" | "goldnugget" | "goldring" | "goldscroll" | "gphelmet" | "greenbomb" | "greenenvelope" | "gslime" | "gstaff" | "gum" | "hammer" | "handofmidas" | "harbringer" | "harmor" | "hboots" | "hbow" | "hdagger" | "heartwood" | "helmet" | "helmet1" | "hgloves" | "hhelmet" | "hotchocolate" | "hpamulet" | "hpants" | "hpbelt" | "hpot0" | "hpot1" | "hpotx" | "iceskates" | "ijx" | "ink" | "intamulet" | "intbelt" | "intearring" | "intring" | "intscroll" | "jacko" | "jewellerybox" | "kitty1" | "lantern" | "lbelt" | "leather" | "ledger" | "licence" | "lifestealscroll" | "lmace" | "lostearring" | "lotusf" | "lspores" | "luckbooster" | "luckscroll" | "luckyt" | "mace" | "maceofthedead" | "mageshood" | "manastealscroll" | "mbelt" | "mbones" | "mcape" | "mcarmor" | "mcboots" | "mcgloves" | "mchat" | "mcpants" | "mearring" | "merry" | "mistletoe" | "mittens" | "mmarmor" | "mmgloves" | "mmhat" | "mmpants" | "mmshoes" | "molesteeth" | "monsterbox" | "monstertoken" | "mparmor" | "mpcostscroll" | "mpgloves" | "mphat" | "mpot0" | "mpot1" | "mpotx" | "mppants" | "mpshoes" | "mpxamulet" | "mpxbelt" | "mpxgloves" | "mrarmor" | "mrboots" | "mrgloves" | "mrhood" | "mrnarmor" | "mrnboots" | "mrngloves" | "mrnhat" | "mrnpants" | "mrpants" | "mshield" | "mushroomstaff" | "mwarmor" | "mwboots" | "mwgloves" | "mwhelmet" | "mwpants" | "mysterybox" | "networkcard" | "nheart" | "northstar" | "offering" | "offeringp" | "offeringx" | "oozingterror" | "orbg" | "orbofdex" | "orbofint" | "orbofsc" | "orbofstr" | "orbofvit" | "ornament" | "ornamentstaff" | "outputscroll" | "oxhelmet" | "pants" | "pants1" | "partyhat" | "phelmet" | "pickaxe" | "pico" | "pinkie" | "placeholder" | "placeholder_m" | "platinumingot" | "platinumnugget" | "pleather" | "pmace" | "poison" | "poker" | "pouchbow" | "powerglove" | "pstem" | "pumpkinspice" | "puppy1" | "puppyer" | "pvptoken" | "pyjamas" | "qubics" | "quiver" | "rabbitsfoot" | "rapier" | "rattail" | "redenvelope" | "redenvelopev2" | "redenvelopev3" | "rednose" | "reflectionscroll" | "resistancering" | "resistancescroll" | "rfangs" | "rfur" | "ringofluck" | "ringsj" | "rod" | "rpiercingscroll" | "sanguine" | "santasbelt" | "scroll0" | "scroll1" | "scroll2" | "scroll3" | "scroll4" | "scythe" | "seashell" | "shadowstone" | "shield" | "shoes" | "shoes1" | "slimestaff" | "smoke" | "smush" | "snakefang" | "snakeoil" | "snowball" | "snowboots" | "snowflakes" | "snring" | "solitaire" | "spear" | "spearofthedead" | "speedscroll" | "spidersilk" | "spores" | "sshield" | "sstinger" | "staff" | "staff2" | "staff3" | "staff4" | "staffofthedead" | "stand0" | "stand1" | "starkillers" | "stealthcape" | "stick" | "stinger" | "stonekey" | "stoneofgold" | "stoneofluck" | "stoneofxp" | "storagebox" | "stramulet" | "strbelt" | "strearring" | "strring" | "strscroll" | "suckerpunch" | "supermittens" | "svenom" | "swifty" | "swirlipop" | "sword" | "swordofthedead" | "t2bow" | "t2dexamulet" | "t2intamulet" | "t2quiver" | "t2stramulet" | "t3bow" | "talkingskull" | "test" | "test2" | "test_orb" | "throwingstars" | "tombkey" | "tracker" | "trigger" | "trinkets" | "tristone" | "troll" | "tshell" | "tshirt0" | "tshirt1" | "tshirt2" | "tshirt3" | "tshirt4" | "tshirt6" | "tshirt7" | "tshirt8" | "tshirt88" | "tshirt9" | "ukey" | "vattire" | "vblood" | "vboots" | "vcape" | "vdagger" | "vgloves" | "vhammer" | "vitearring" | "vitring" | "vitscroll" | "vorb" | "vring" | "vstaff" | "vsword" | "wand" | "warmscarf" | "warpvest" | "watercore" | "wattire" | "wbasher" | "wblade" | "wbook0" | "wbook1" | "wbreeches" | "wcap" | "weaponbox" | "weaver" | "wgloves" | "whiskey" | "whiteegg" | "wine" | "wingedboots" | "woodensword" | "wshield" | "wshoes" | "x0" | "x1" | "x2" | "x3" | "x4" | "x5" | "x6" | "x7" | "x8" | "xarmor" | "xboots" | "xbox" | "xgloves" | "xhelmet" | "xmace" | "xmashat" | "xmaspants" | "xmasshoes" | "xmassweater" | "xpants" | "xpbooster" | "xpscroll" | "xptome" | "xshield" | "xshot";
export declare type MapName = "abtesting" | "arena" | "bank" | "bank_b" | "bank_u" | "batcave" | "cave" | "cgallery" | "crypt" | "cyberland" | "d1" | "d2" | "d3" | "d_a1" | "d_a2" | "d_b1" | "d_e" | "d_g" | "desertland" | "duelland" | "dungeon0" | "frozencave" | "goobrawl" | "halloween" | "hut" | "jail" | "level1" | "level2" | "level2e" | "level2n" | "level2s" | "level2w" | "level3" | "level4" | "main" | "maintest" | "mansion" | "mtunnel" | "old_bank" | "old_main" | "original_main" | "resort" | "resort_e" | "shellsisland" | "ship0" | "spookytown" | "tavern" | "test" | "therush" | "tomb" | "tunnel" | "winter_cave" | "winter_inn" | "winter_inn_rooms" | "winterland" | "woffice";
export declare type MonsterName = "a1" | "a2" | "a3" | "a4" | "a5" | "a6" | "a7" | "a8" | "arcticbee" | "armadillo" | "bat" | "bbpompom" | "bee" | "bigbird" | "bluefairy" | "boar" | "booboo" | "bscorpion" | "cgoo" | "chestm" | "crab" | "crabx" | "croc" | "cutebee" | "d_wiz" | "dknight2" | "dragold" | "eelemental" | "ent" | "felemental" | "fieldgen0" | "fireroamer" | "franky" | "frog" | "fvampire" | "gbluepro" | "ggreenpro" | "ghost" | "goblin" | "goldenbat" | "goo" | "gpurplepro" | "gredpro" | "greenfairy" | "greenjr" | "grinch" | "gscorpion" | "hen" | "iceroamer" | "jr" | "jrat" | "kitty1" | "kitty2" | "kitty3" | "kitty4" | "ligerx" | "mechagnome" | "minimush" | "mole" | "mrgreen" | "mrpumpkin" | "mummy" | "mvampire" | "nelemental" | "nerfedmummy" | "oneeye" | "osnake" | "phoenix" | "pinkgoblin" | "pinkgoo" | "plantoid" | "poisio" | "porcupine" | "pppompom" | "prat" | "puppy1" | "puppy2" | "puppy3" | "puppy4" | "rat" | "redfairy" | "rooster" | "rudolph" | "scorpion" | "skeletor" | "snake" | "snowman" | "spider" | "squig" | "squigtoad" | "stompy" | "stoneworm" | "target" | "target_a500" | "target_a750" | "target_ar500red" | "target_ar900" | "target_r500" | "target_r750" | "terracota" | "tinyp" | "tortoise" | "vbat" | "wabbit" | "welemental" | "wolf" | "wolfie" | "xscorpion" | "zapper0";
export declare type NPCName = "antip2w" | "appearance" | "armors" | "basics" | "bean" | "beans" | "bouncer" | "citizen0" | "citizen1" | "citizen10" | "citizen11" | "citizen12" | "citizen13" | "citizen14" | "citizen15" | "citizen2" | "citizen3" | "citizen4" | "citizen5" | "citizen6" | "citizen7" | "citizen8" | "citizen9" | "compound" | "craftsman" | "exchange" | "fancypots" | "firstc" | "fisherman" | "funtokens" | "gemmerchant" | "goldnpc" | "guard" | "holo" | "holo0" | "holo1" | "holo2" | "holo3" | "holo4" | "holo5" | "items0" | "items1" | "items10" | "items11" | "items12" | "items13" | "items14" | "items15" | "items16" | "items17" | "items18" | "items19" | "items2" | "items20" | "items21" | "items22" | "items23" | "items24" | "items25" | "items26" | "items27" | "items28" | "items29" | "items3" | "items30" | "items31" | "items32" | "items33" | "items34" | "items35" | "items36" | "items37" | "items38" | "items39" | "items4" | "items40" | "items41" | "items42" | "items43" | "items44" | "items45" | "items46" | "items47" | "items5" | "items6" | "items7" | "items8" | "items9" | "jailer" | "leathermerchant" | "lichteaser" | "locksmith" | "lostandfound" | "lotterylady" | "mcollector" | "mistletoe" | "monsterhunter" | "newupgrade" | "newyear_tree" | "ornaments" | "pete" | "pots" | "premium" | "princess" | "pvp" | "pvpblocker" | "pvptokens" | "pwincess" | "rewards" | "santa" | "scrolls" | "secondhands" | "shellsguy" | "ship" | "shrine" | "standmerchant" | "tavern" | "tbartender" | "thief" | "transporter" | "wbartender" | "weapons" | "witch" | "wizardrepeater" | "wnpc";
export declare type ProjectileName = "acid" | "arrow" | "bigmagic" | "burst" | "crossbowarrow" | "cupid" | "curse" | "firearrow" | "fireball" | "frostarrow" | "frostball" | "garrow" | "magic" | "magic_divine" | "magic_purple" | "mmagic" | "momentum" | "pinky" | "plight" | "pmagic" | "poisonarrow" | "pouch" | "snowball" | "stone" | "stone_k" | "supershot" | "wandy" | "wmomentum";
export declare type SkillName = "3shot" | "4fingers" | "5shot" | "absorb" | "agitate" | "alchemy" | "anger" | "attack" | "blink" | "burst" | "cburst" | "charge" | "charm" | "cleave" | "curse" | "curse_aura" | "dampening_aura" | "darkblessing" | "emotion" | "energize" | "entangle" | "esc" | "fishing" | "gm" | "hardshell" | "heal" | "healing" | "huntersmark" | "interact" | "invis" | "light" | "magiport" | "massproduction" | "massproductionpp" | "mcourage" | "mentalburst" | "mining" | "mlight" | "mluck" | "move_down" | "move_left" | "move_right" | "move_up" | "mshield" | "mtangle" | "multi_burn" | "multi_freeze" | "open_snippet" | "partyheal" | "pcoat" | "phaseout" | "piercingshot" | "poisonarrow" | "portal" | "power" | "pure_eval" | "quickpunch" | "quickstab" | "reflection" | "regen_hp" | "regen_mp" | "revive" | "rspeed" | "scare" | "self_healing" | "selfheal" | "shadowstrike" | "snippet" | "snowball" | "stack" | "stomp" | "stone" | "stop" | "supershot" | "tangle" | "taunt" | "throw" | "toggle_character" | "toggle_code" | "toggle_inventory" | "toggle_run_code" | "toggle_stats" | "track" | "travel" | "use_hp" | "use_mp" | "use_town" | "warcry" | "warp" | "weakness_aura" | "xpower" | "zap";
export declare type TilesetName = "ash" | "beach" | "castle" | "custom" | "custom2" | "custom_a" | "dark" | "doors" | "dungeon" | "fort" | "house" | "inside" | "jungle" | "licht" | "new" | "outside" | "puzzle" | "ruins" | "ship" | "stands" | "tree" | "water" | "winter";
export declare type TitleName = "critmonger" | "fast" | "festive" | "firehazard" | "glitched" | "gooped" | "legacy" | "lucky" | "shiny" | "sniper" | "stomped" | "superfast";
export declare type QuestName = ItemName | "cx" | "mcollector" | "witch";
